@@ -1,4 +1,4 @@
-pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="Time", colConc="conc", dose=0, adm="Extravascular", dur=0, doseUnit="mg", timeUnit="h", concUnit="ug/L", down="Linear", R2ADJ=0, MW=0, iAUC)
+pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="Time", colConc="conc", dose=0, adm="Extravascular", dur=0, doseUnit="mg", timeUnit="h", concUnit="ug/L", down="Linear", R2ADJ=0, MW=0, iAUC="", excludeDelta=1)
 {
   defPar = par(no.readonly=TRUE)
 
@@ -35,7 +35,7 @@ pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="T
     if (nrow(tData) > 0) {
       x = tData[,colTime]
       y = tData[,colConc]
-      tabRes = sNCA(x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, R2ADJ=R2ADJ, MW=MW, iAUC=iAUC)
+      tabRes = sNCA(x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, timeUnit=timeUnit, concUnit=concUnit, down=down, R2ADJ=R2ADJ, MW=MW, iAUC=iAUC, Keystring=strHeader, excludeDelta=excludeDelta)
       UsedPoints = attr(tabRes, "UsedPoints")
       txtRes = Res2Txt(tabRes, x, y, dose=dose[i], adm=adm, dur=dur, doseUnit=doseUnit, down=down)
       Res = c(Res, txtRes)
@@ -61,17 +61,19 @@ pdfNCA = function(fileName="Temp-NCA.pdf", concData, key = "Subject", colTime="T
       par(oma=c(1,1,1,1), mar=c(4,4,3,1), adj=0.5)
       x0 = x[!is.na(y) & y > 0]
       y0 = y[!is.na(y) & y > 0]
-      plot(x0, log10(y0), type="b", cex=0.7, xlim=c(0, maxx), ylim=c(log10(miny), log10(maxy)), yaxt="n", xlab=paste0("Time (", timeUnit, ")"), ylab=paste0("Concentration (log interval) (", concUnit, ")"))
-      points(x[UsedPoints], log10(y[UsedPoints]), pch=16)
-      yticks = seq(round(min(log10(y0))), ceiling(max(log10(y0))))
-      ylabels = sapply(yticks, function(i) as.expression(bquote(10^ .(i))))
-      axis(2, at=yticks, labels=ylabels)
-      x1 = tabRes["LAMZLL"]
-      x2 = tabRes["LAMZUL"]
-      deltaX = x1 * 0.05
-      y1 = log10(2.718281828)*(tabRes["b0"] - tabRes["LAMZ"] * (x1 - deltaX))
-      y2 = log10(2.718281828)*(tabRes["b0"] - tabRes["LAMZ"] * (x2 + deltaX))
-      lines(c(x1 - deltaX, x2 + deltaX), c(y1, y2), lty=2, col="red")
+      if (length(x0) > 0) { 
+        plot(x0, log10(y0), type="b", cex=0.7, xlim=c(0, maxx), ylim=c(log10(miny), log10(maxy)), yaxt="n", xlab=paste0("Time (", timeUnit, ")"), ylab=paste0("Concentration (log interval) (", concUnit, ")"))
+        points(x[UsedPoints], log10(y[UsedPoints]), pch=16)
+        yticks = seq(round(min(log10(y0))), ceiling(max(log10(y0))))
+        ylabels = sapply(yticks, function(i) as.expression(bquote(10^ .(i))))
+        axis(2, at=yticks, labels=ylabels)
+        x1 = tabRes["LAMZLL"]
+        x2 = tabRes["LAMZUL"]
+        deltaX = x1 * 0.05
+        y1 = log10(2.718281828)*(tabRes["b0"] - tabRes["LAMZ"] * (x1 - deltaX))
+        y2 = log10(2.718281828)*(tabRes["b0"] - tabRes["LAMZ"] * (x2 + deltaX))
+        lines(c(x1 - deltaX, x2 + deltaX), c(y1, y2), lty=2, col="red")
+      }
       close.screen(all.screens=TRUE)
     }
   }
